@@ -1,7 +1,3 @@
-/* 
- * $Xorg: xset.c,v 1.6 2001/02/09 02:05:58 xorgcvs Exp $
- */
-
 /*
 
 Copyright 1985, 1998  The Open Group
@@ -27,7 +23,6 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
-/* $XFree86: xc/programs/xset/xset.c,v 3.31 2003/05/27 22:27:09 tsi Exp $ */
 /* Modified by Stephen so keyboard rate is set using XKB extensions */
 
 #ifdef HAVE_CONFIG_H
@@ -50,10 +45,6 @@ in this Software without prior written authorization from The Open Group.
 # define XF86MISC
 #endif
 
-#if defined(HAVE_X11_EXTENSIONS_PRINT_H)
-# define BUILD_PRINTSUPPORT
-#endif
-
 #if defined(HAVE_X11_EXTENSIONS_FONTCACHE_H) && defined(HAVE_X11_EXTENSIONS_FONTCACHEP_H)
 # define FONTCACHE
 #endif
@@ -108,9 +99,6 @@ in this Software without prior written authorization from The Open Group.
 static Status set_font_cache(Display *, long, long, long);
 static void query_cache_status(Display *dpy);
 #endif
-#ifdef BUILD_PRINTSUPPORT
-# include <X11/extensions/Print.h>
-#endif
 
 #define ON 1
 #define OFF 0
@@ -378,19 +366,6 @@ main(int argc, char *argv[])
 			"server does not have extension for fc option\n");
 	    }
 	}
-#endif
-#ifdef BUILD_PRINTSUPPORT
-	else if (strcmp(arg, "rehashprinterlist") == 0) {
-	    /* rehash list of printers */
-	    short dummy;
-
-	    if (XpQueryVersion(dpy, &dummy, &dummy)) {
-		XpRehashPrinterList(dpy);
-	    } else {
-		fprintf(stderr,
-			"server does not have extension for rehashprinterlist option\n");
-	    }
-	}
 #endif
 	else if (strcmp(arg, "fp") == 0) {	/* set font path */
 	    if (i >= argc) {
@@ -593,7 +568,7 @@ main(int argc, char *argv[])
 		     *
 		     * On OS/2, use _sleep2()
 		     */
-		    
+
 #ifdef HAVE_USLEEP
 # define Usleep(us) usleep((us))
 #else
@@ -954,7 +929,7 @@ set_font_path(Display *dpy, char *path, int special, int before, int after)
     }
 
     /*
-     * parse the path list.  If before or after is non-zero, we'll need 
+     * parse the path list.  If before or after is non-zero, we'll need
      * the current value.
      */
 
@@ -1334,7 +1309,6 @@ query(Display *dpy)
     XKeyboardState values;
     int acc_num, acc_denom, threshold;
     int timeout, interval, prefer_blank, allow_exp;
-    int dummy;
 
 #ifdef XF86MISC
     XF86MiscKbdSettings kbdinfo;
@@ -1384,9 +1358,6 @@ query(Display *dpy)
 
 	    if (XGetAtomNames(dpy, iatoms, j, iatomnames)) {
 		for (i = 0; i < j; i++) {
-		    Bool state;
-		    int ind;
-
 		    if (XkbGetNamedIndicator(dpy, iatoms[i], &inds[i],
 					     &istates[i], NULL, NULL)) {
 			int namelen = strlen(iatomnames[i]);
@@ -1448,10 +1419,14 @@ query(Display *dpy)
 #endif
 #endif
 #ifdef XF86MISC
-    if (XF86MiscQueryExtension(dpy, &dummy, &dummy) &&
-	XF86MiscGetKbdSettings(dpy, &kbdinfo))
-	printf("  auto repeat delay:  %d    repeat rate:  %d\n",
-	       kbdinfo.delay, kbdinfo.rate);
+    {
+	int dummy;
+
+	if (XF86MiscQueryExtension(dpy, &dummy, &dummy) &&
+	    XF86MiscGetKbdSettings(dpy, &kbdinfo))
+	    printf("  auto repeat delay:  %d    repeat rate:  %d\n",
+	           kbdinfo.delay, kbdinfo.rate);
+    }
 #endif
     printf("  auto repeating keys:  ");
     for (i = 0; i < 4; i++) {
@@ -1680,15 +1655,10 @@ usage(char *fmt, ...)
 #ifdef FONTCACHE
     fprintf(stderr, "    To control font cache:\n");
     fprintf(stderr, "\t fc [hi-mark [low-mark [balance]]]\n");
-    fprintf(stderr, "\t    both mark values spcecified in KB\n");
-    fprintf(stderr, "\t    balance value spcecified in percent (10 - 90)\n");
+    fprintf(stderr, "\t    both mark values specified in KB\n");
+    fprintf(stderr, "\t    balance value specified in percent (10 - 90)\n");
     fprintf(stderr, "    Show font cache statistics:\n");
     fprintf(stderr, "\t fc s\n");
-#endif
-#ifdef BUILD_PRINTSUPPORT
-    fprintf(stderr, "    To control Xprint features:\n");
-    fprintf(stderr,
-	"\t rehashprinterlist      Recomputes the list of available printers\n");
 #endif
     fprintf(stderr, "    To set the font path:\n");
     fprintf(stderr, "\t fp= path[,path...]\n");
